
<!---
FrozenIsBool True
-->

##Example

Some useful derived List class that helps to get and set automatically in a mapping way.
Here is the example of the GetList that returns always a list of things or getted things if a GetterVariable is also specified.